#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : icons
# @Time         : 2024/11/21 15:45
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : https://lobechat.com/

# https://lobehub.com/zh/icons


chatfire = "https://registry.npmmirror.com/@lobehub/assets-emoji-anim/1.0.0/files/assets/cowboy-hat-face.webp"

openai = "https://api.bltcy.ai/logos/openai.png"
openai_plus = "https://api.bltcy.ai/logos/openai-plus.png"
claude = "https://api.bltcy.ai/logos/claude.png"

kuaishou_kling = "https://api.bltcy.ai/logos/kling.png"
flux = "https://api.bltcy.ai/logos/flux.png"
ideogram = "https://api.bltcy.ai/logos/Ideogram.png"
moonshot = "https://api.bltcy.ai/logos/moonshot.png"
google = "https://api.bltcy.ai/logos/google.png"

zhipu = "https://api.bltcy.ai/logos/zhipuai.png"
deepseek = "https://api.bltcy.ai/logos/deepseek.png"
baichuan = "https://api.bltcy.ai/logos/bai-chuang-zhi-neng.png"
lingyi = "https://api.bltcy.ai/logos/lingyiwanwu.png"
doubao = "https://api.bltcy.ai/logos/doubao.png"
